## Hierarchical clustering using 4N: usage demo file
## version 0.24 / March 2015 for "Towards a hierarchical strategy for finding protein complexes in multi scale IP/MS data"
## (c) 2015/2016, Joachim Kutzera, j.kutzera@uva.nl



## you have to set the directory to where the file HC4N.R is.
setwd("yoursourcedrive/HC4N_toolbox")

## general note: you need the R-package RBGL installed to make this work. RBGL needs R version >3.0.2. 


source("HC4N.R")
options(error = recover) ## when something goes wrong, you want to see where.

## loading the AP/MS data matrix (subset from original dataset gavinBP2006 which would be available from the bioconductor package "apComplex")
d = read.delim(file="g2006_POL_SOI.tsv", header=T, sep="\t")
g2006_POL = as.matrix(d[,-1])
rownames(g2006_POL) = d[,1] ## the rownames incicate the POL assignment for the reader, HC4N ignores the rownames, but they need to be unique.

HCresult = HC4N(g2006_POL,verbose=T) ## running HC4N with automatic setup

## HC4N tells us that the automatic parameters are U=0.25 (co-occurrence parameter) and S=0.64 (set completeness parameter)
## note that HC4N creates 8 level 1 clusters.

HCplot = hierarchicalClusterPlot(g2006_POL, HCresult, startU=0.1, useHM=T) ## creating the HC-plot. startU must be below used U and only influences the image order.
plotHCplot(HCplot, labelType=2, legendCex=1, textCex=1, useSqrt=T) ## plotting the HC plot, useSqrt gives brighter colors when the general co-occurrence is low

## we see that, although we know that the dataset contains overlapping complexes, the clusters are hardly connected because the parameters are too high.
## we change the co-occurrence parameter to 0.2, the setwise completeness parameter to 0.5.

HCresult = HC4N(g2006_POL,startU = 0.2, startS=0.5,verbose=T) 

## now, HC4N creates only four level 1 clusters.

HCplot = hierarchicalClusterPlot(g2006_POL, HCresult, startU=0.1, useHM=T)
plotHCplot(HCplot, labelType=2, legendCex=1, textCex=1, useSqrt=T)

## The typical pattern indicating shared proteins is visible for four proteins which are in fact shared between the complexes.
## Most proteins that exclusively belong to one complex are separated correctly.

## exporting the result as tree graph for cytoscape

exportTree(HCresult, rownames(g2006_POL), outfilename="HC4N_graph")

## Two files are written,  An edge file:

Node1	Node2
1	0
2	1
3	1
4	3
...

## and a node attribute file:

Node	Level	co-occurrence	type	proteins
5	3	0.5	2 proteins left	["YNR003C_2","YPR190C_2"]
6	3	0.5625	2 proteins left	["YOR207C_2","YNR003C_2"]
7	2	0.6	2 proteins left	["YDL150W_2","YKR025W_2"]
8	2	0.5263158	2 proteins left	["YPR187W_123","YBR154C_123"]
9	2	0.7	2 proteins left	["YOR224C_123","YBR154C_123"]
10	2	0.4	2 proteins left	["YPR190C_2","YPR110C_12"]
11	2	0.5	2 proteins left	["YDR045C_2","YDR005C"]
...

## "type" is the reason why a node is a leaf. The entry is "no" when a node is a inner node with children nodes. 

## the edge file is imported into cytoscape and the network should be expanded using the "organic" visual style.
## the node attributes is then imported. The "proteins" column can be imported as list of strings to see all proteins in the node names.
## node color should be mapped as continous mapping to the co-occurrence value.


